#!/usr/bin/Rscript

# Xavier Fernández i Marín
# http://xavier-fim.net
# 28/10/2020

# Purpose: to  generate scores of salience of every issue for every country
# This is done be weighting the seats of every party in the parliament by
# the importance they give to environmental/social issues

# It assumes that once elections are held, salience holds until 
# the next recorded election

# Environmental is 501, Environmental protection
# Social is 504, Welfare State Expansion

library(dplyr)
library(tidyr)
library(ggplot2)
library(colorspace)

orig <- read.table("./MPDataset_MPDS2020a.csv", header=TRUE, sep=",")


d.parties <- orig %>%
  as_tibble() %>%
  mutate(p.vote = pervote) %>%
  mutate(Country = countryname,
         Date = as.Date(as.character(edate), format = "%d/%m/%Y")) %>%
  mutate(Environmental = per501,
         Social = per504) %>%
  select(Country, Date, p.vote, Environmental, Social) %>%
  gather(Sector, importance, -c(Country, Date, p.vote)) %>%
  # Weight importance by proportion of vote
  mutate(Salience = p.vote * importance)


d.country <- d.parties %>%
  group_by(Country, Date, Sector) %>%
  summarize(Salience = sum(Salience)) %>%
  ungroup()


universe <- expand_grid(
  Country = unique(d.parties$Country),
  Sector = unique(d.parties$Sector),
  Year = format(min(d.parties$Date), "%Y"):format(max(d.parties$Date), "%Y"))

d.year <- d.country %>%
  mutate(Year = as.integer(format(Date, "%Y"))) %>%
  group_by(Sector, Country, Year) %>%
  summarize(Salience = mean(Salience)) %>%
  ungroup() %>%
  right_join(universe) %>%
  group_by(Sector, Country) %>%
  arrange(Sector, Country, Year) %>%
  fill(Salience) %>%
  ungroup()





# Figures
ggplot(d.parties, aes(x = Date, y = importance, color = Sector)) +
  geom_point() +
  geom_line() +
  facet_wrap(~ Country) +
  scale_color_discrete_qualitative(palette = "Set 2") +
  ggtitle("Importance")

ggplot(d.country, aes(x = Date, y = Salience, color = Sector)) +
  geom_point() +
  geom_line() +
  facet_wrap(~ Country) +
  scale_color_discrete_qualitative(palette = "Set 2") +
  ggtitle("Aggregated salience, election to election")

ggplot(d.year, aes(x = Year, y = Salience, color = Sector)) +
  geom_point() +
  geom_line() +
  facet_wrap(~ Country) +
  scale_color_discrete_qualitative(palette = "Set 2") +
  ggtitle("Aggregated salience, yearly")



cpm.salience <- d.year
save(cpm.salience, file="201029-cpm-salience.RData")
